# Sistema de Ecuaciones

Esta librería es para resolver sistemas de ecuaciones lineales y no lineales utilizando los siguientes métodos:

- Eliminación de Gauss
- Gauss-Jordan
- Cramer
- Descomposición LU
- Jacobi
- Gauss-Seidel
- Bisección

## Instalación

Para instalarlo solo se debe anteponer el comando pip


